Module: Cms::ApplicationHelper
- Defined in:
- app/helpers/cms/application_helper.rb
Instance Method Summary collapse
- #action_icon(name, options = {}) ⇒ Object
- #action_icon_src(name) ⇒ Object
-
#add_button(path, options = {}) ⇒ Object
Render a CMS styled 'Add' button.
-
#categories_for(category_type_name, order = "name") ⇒ Object
Fetches a list of categories for a cms_drop_down.
-
#check_uncheck_tag(selector) ⇒ Object
Renders two links that will check/uncheck a set of checkboxes.
- #cms_handler_path(*args) ⇒ Object deprecated Deprecated.
-
#delete_button(options = {}) ⇒ Object
Render a CMS styled 'X Delete' button.
- #determine_order(current_order, order) ⇒ Object
- #dk_button_wrapper(content) ⇒ Object
-
#edit_button(options = {}) ⇒ Object
Render a CMS styled 'Edit' button.
- #format_date(time) ⇒ Object
- #group_filter ⇒ Object
- #group_ids ⇒ Object
-
#link_to_check_all(selector, name = "Check All") ⇒ Object
deprecated
Deprecated.
Use check_uncheck_tag instead. Retained for backwards compatibility w/ CMS implementations.
-
#link_to_uncheck_all(selector, name = "Uncheck All") ⇒ Object
deprecated
Deprecated.
Use check_uncheck_tag instead. Retained for backwards compatibility w/ CMS implementations.
- #link_to_usages(block) ⇒ Object
- #lt_button_wrapper(content) ⇒ Object
- #page_versions(page) ⇒ Object
- #render_pagination(collection, collection_name, options = {}) ⇒ Object
- #searchable_sections(selected = nil) ⇒ Object
- #select_per_page ⇒ Object
- #span_tag(content) ⇒ Object
- #status_icon(status, options = {}) ⇒ Object
- #time_on_date(time) ⇒ Object
- #url_with_mode(url, mode) ⇒ Object
Instance Method Details
#action_icon(name, options = {}) ⇒ Object
37 38 39 |
# File 'app/helpers/cms/application_helper.rb', line 37 def action_icon(name, ={}) image_tag action_icon_src(name), {:alt => name.to_s.titleize}.merge() end |
#action_icon_src(name) ⇒ Object
33 34 35 |
# File 'app/helpers/cms/application_helper.rb', line 33 def action_icon_src(name) "cms/icons/actions/#{name}.png" end |
#add_button(path, options = {}) ⇒ Object
Render a CMS styled 'Add' button. This button will appear on tool bars, typically set apart visually from other buttons.
235 236 237 238 239 |
# File 'app/helpers/cms/application_helper.rb', line 235 def (path, ={}) classes = "button" = {:class => classes} link_to span_tag(" Add ".html_safe), path, end |
#categories_for(category_type_name, order = "name") ⇒ Object
Fetches a list of categories for a cms_drop_down. Will prompt users to create Categories/Categories types if the proper ones don't exist.
150 151 152 153 154 |
# File 'app/helpers/cms/application_helper.rb', line 150 def categories_for(category_type_name, order="name") cat_type = CategoryType.named(category_type_name).first categories = cat_type ? cat_type.category_list(order) : [Category.new(:name=>"-- You must first create a 'Category Type' named '#{category_type_name}'")] categories.empty? ? [Category.new(:name=>"-- You must first create a Category with a Category Type of '#{category_type_name}'.")]: categories end |
#check_uncheck_tag(selector) ⇒ Object
Renders two links that will check/uncheck a set of checkboxes.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'app/helpers/cms/application_helper.rb', line 67 def check_uncheck_tag(selector) check_id = to_id(selector, "check") uncheck_id = to_id(selector, "uncheck") content_for :html_head do html = <<HTML jQuery(function($) { $('a##{check_id}').click(function() { $('#{selector}').attr('checked', true); }); $('a##{uncheck_id}').click(function() { $('#{selector}').attr('checked', false); }); }) HTML javascript_tag html end "#{link_to "Check All", '#', :id=>check_id}, #{link_to "Uncheck All", '#', :id=>uncheck_id}".html_safe end |
#cms_handler_path(*args) ⇒ Object
Help with deprecations messages
7 8 9 |
# File 'app/helpers/cms/application_helper.rb', line 7 def cms_handler_path(*args) raise "The #cms_handler_path helper method has been removed from BrowserCMS. Use '#handler_path instead'." end |
#delete_button(options = {}) ⇒ Object
Render a CMS styled 'X Delete' button. This button will appear on tool bars, typically set apart visually from other buttons. Has a 'confirm?' popup attached to it as well. Assumes that javascript code to handle the 'confirm' has already been included in the page.
204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'app/helpers/cms/application_helper.rb', line 204 def (={}) classes = "button" classes << " disabled" if ![:enabled] classes << " delete_button" classes << " http_delete confirm_with_title" if [:title] link_to_path = [:path] ? [:path] : "#" = {:id => 'delete_button', :class => classes} [:title] = [:title] if (![:title].blank? && [:title].class == String) link_to span_tag("<span class=\"delete_img\"> </span>Delete".html_safe), link_to_path, end |
#determine_order(current_order, order) ⇒ Object
184 185 186 187 188 189 190 191 192 193 194 |
# File 'app/helpers/cms/application_helper.rb', line 184 def determine_order(current_order, order) if current_order == order if order =~ / desc$/i order.sub(/ desc$/i, '') else order << ' desc' end else order end end |
#dk_button_wrapper(content) ⇒ Object
137 138 139 |
# File 'app/helpers/cms/application_helper.rb', line 137 def (content) (content).gsub("lt_button_", "dk_button_") end |
#edit_button(options = {}) ⇒ Object
Render a CMS styled 'Edit' button. This button will appear on tool bars, typically set apart visually from other buttons.
222 223 224 225 226 227 228 229 230 |
# File 'app/helpers/cms/application_helper.rb', line 222 def (={}) classes = "button" classes << " disabled" if ![:enabled] link_to_path = [:path] ? [:path] : "#" = {:id => 'edit_button', :class => classes} link_to span_tag(" Edit ".html_safe), link_to_path, end |
#format_date(time) ⇒ Object
60 61 62 |
# File 'app/helpers/cms/application_helper.rb', line 60 def format_date(time) time && "#{time.strftime("%b %e, %Y")}" end |
#group_filter ⇒ Object
145 146 147 |
# File 'app/helpers/cms/application_helper.rb', line 145 def group_filter select_tag("group_id", (Group.all.insert(0, Group.new(:id => nil, :name => "Show All Groups")), "id", "name", params[:group_id].to_i)) end |
#group_ids ⇒ Object
141 142 143 |
# File 'app/helpers/cms/application_helper.rb', line 141 def group_ids (params[:group_ids] || @user.group_ids).collect { |g| g.to_i } end |
#link_to_check_all(selector, name = "Check All") ⇒ Object
Use check_uncheck_tag instead. Retained for backwards compatibility w/ CMS implementations.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'app/helpers/cms/application_helper.rb', line 89 def link_to_check_all(selector, name="Check All") id = to_id(selector, "check") content_for :html_head do html = <<HTML jQuery(function($) { $('a##{id}').click(function() { $('#{selector}').attr('checked', true); }); }) HTML javascript_tag html end link_to name, '#', :id=>id end |
#link_to_uncheck_all(selector, name = "Uncheck All") ⇒ Object
Use check_uncheck_tag instead. Retained for backwards compatibility w/ CMS implementations.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'app/helpers/cms/application_helper.rb', line 105 def link_to_uncheck_all(selector, name="Uncheck All") id = to_id(selector, "uncheck") content_for :html_head do html = <<HTML jQuery(function($) { $('a##{id}').click(function() { $('#{selector}').attr('checked', false); }); }) HTML javascript_tag html end link_to name, '#', :id=>id end |
#link_to_usages(block) ⇒ Object
45 46 47 48 49 50 51 52 53 54 |
# File 'app/helpers/cms/application_helper.rb', line 45 def link_to_usages(block) count = block.connected_pages.count if count > 0 # Would love a cleaner solution to this problem, see http://stackoverflow.com/questions/702728 path = Portlet === block ? usages_portlet_path(block) : [:usages, block] link_to count, path, :id => block.id, :block_type => block.content_block_type else count end end |
#lt_button_wrapper(content) ⇒ Object
124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'app/helpers/cms/application_helper.rb', line 124 def (content) = <<LBW <div class="lt_button"> #{image_tag "cms/lt_button_l.gif"} <div class="lt_button_content"> <span>#{ content }</span> </div> #{image_tag "cms/lt_button_r.gif", :style=>"margin-right: 10px;"} </div> LBW .html_safe end |
#page_versions(page) ⇒ Object
23 24 25 26 27 28 29 30 31 |
# File 'app/helpers/cms/application_helper.rb', line 23 def page_versions(page) text = select_tag(:version, (page.versions.all(:order => "version desc").map { |r| ["v#{r.version}: #{r.version_comment} by #{r.updated_by.login} at #{time_on_date(r.updated_at)}", r.version] }, page.version), :onchange => 'this.form.submit(); return false') text << javascript_tag("$('version').selectedIndex = 0") if page.live? text end |
#render_pagination(collection, collection_name, options = {}) ⇒ Object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'app/helpers/cms/application_helper.rb', line 156 def render_pagination(collection, collection_name, ={}) if collection.blank? content_tag(:div, "No Content", :class => "pagination") else collection_path = "#{collection_name}_path" render :partial => "cms/shared/pagination", :locals => { :collection => collection, :first_page_path => send(collection_path, {:page => 1}.merge()), :previous_page_path => send(collection_path, {:page => collection.previous_page ? collection.previous_page : 1}.merge()), :current_page_path => send(collection_path, ), :next_page_path => send(collection_path, {:page => collection.next_page ? collection.next_page : collection.current_page}.merge()), :last_page_path => send(collection_path, {:page => collection.total_pages}.merge()) } end end |
#searchable_sections(selected = nil) ⇒ Object
11 12 13 14 15 16 |
# File 'app/helpers/cms/application_helper.rb', line 11 def searchable_sections(selected = nil) root = Section.root.first = [['All sections', 'all'], [root.name, root.id]] root.master_section_list.each { |s| << [s.full_path, s.id] } (, selected.to_i) end |
#select_per_page ⇒ Object
18 19 20 21 |
# File 'app/helpers/cms/application_helper.rb', line 18 def select_per_page = [10, 20, 50, 100].collect { |c| ["#{c} per page", c] } select_tag("per_page", (, params[:per_page].to_i)) end |
#span_tag(content) ⇒ Object
120 121 122 |
# File 'app/helpers/cms/application_helper.rb', line 120 def span_tag(content) content_tag :span, content end |
#status_icon(status, options = {}) ⇒ Object
41 42 43 |
# File 'app/helpers/cms/application_helper.rb', line 41 def status_icon(status, ={}) image_tag "cms/icons/status/#{status.to_s.underscore}.gif", {:alt => status.to_s.titleize}.merge() end |
#time_on_date(time) ⇒ Object
56 57 58 |
# File 'app/helpers/cms/application_helper.rb', line 56 def time_on_date(time) time && "#{time.strftime("%l:%M %p")} on #{time.strftime("%b %e, %Y")}" end |
#url_with_mode(url, mode) ⇒ Object
172 173 174 175 176 177 178 179 180 181 182 |
# File 'app/helpers/cms/application_helper.rb', line 172 def url_with_mode(url, mode) url = "" unless url # Handles cases where request.referrer is nil (see cms/_page_toolbar.html.erb for an example) uri = URI.parse(url) if uri.query =~ /mode=[^&]*/ "#{uri.path}?#{uri.query.gsub(/((^|&)mode=)[^&]*/) { |s| "#{$1}#{mode}" }}" elsif uri.query "#{uri.path}?#{uri.query}&mode=#{mode}" else "#{uri.path}?mode=#{mode}" end end |