Method: Cms::IgnoreSanitizer#sanitize

Defined in:
lib/cms/behaviors/versioning.rb

#sanitize(attributes, authorizer) ⇒ Object

Skip sanitizing attributes from mass assignment. This should be used sparingly, since it bypasses security. Ideally used for dynamically created classes (like ::Version or ::Attribute) where the attributes are not known at design time.



8
9
10
# File 'lib/cms/behaviors/versioning.rb', line 8

def sanitize(attributes, authorizer)
  attributes
end