Class: Page

Inherits:
ActiveRecord::Base
  • Object
show all
Defined in:
app/models/page.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.find_live_by_path(path) ⇒ Object



288
289
290
# File 'app/models/page.rb', line 288

def self.find_live_by_path(path)
  published.not_archived.first(:conditions => {:path => path})
end

Instance Method Details

#after_build_new_version(new_version) ⇒ Object



73
74
75
76
77
78
79
80
# File 'app/models/page.rb', line 73

def after_build_new_version(new_version)
  copy_connectors(
    :from_version_number => @copy_connectors_from_version || (new_version.version - 1),
    :to_version_number => new_version.version
  )
  @copy_connectors_from_version = nil
  true
end

#after_publishObject

Publish all



83
84
85
86
87
88
89
90
# File 'app/models/page.rb', line 83

def after_publish
  self.reload # Get's the correct version number loaded
  self.connectors.for_page_version(self.version).all(:order => "position").each do |c| 
    if c.connectable_type.constantize.publishable? && con = c.connectable
      con.publish
    end
  end
end

#ancestorsObject



264
265
266
# File 'app/models/page.rb', line 264

def ancestors
  section_node.ancestors
end

#append_leading_slash_to_pathObject



231
232
233
234
235
236
237
# File 'app/models/page.rb', line 231

def append_leading_slash_to_path
  if path.blank?
    self.path = "/"
  elsif path[0,1] != "/"
    self.path = "/#{path}"
  end
end

#assigned_toObject



309
310
311
# File 'app/models/page.rb', line 309

def assigned_to
  current_task ? current_task.assigned_to : nil
end

#assigned_to?(user) ⇒ Boolean

Returns:

  • (Boolean)


313
314
315
# File 'app/models/page.rb', line 313

def assigned_to?(user)
  assigned_to == user
end

#connectable_count_for_container(container) ⇒ Object

Returns the number of connectables in the given container for this version of this page



284
285
286
# File 'app/models/page.rb', line 284

def connectable_count_for_container(container)
  connectors.for_page_version(version).in_container(container.to_s).count
end

#container_published?(container) ⇒ Boolean

Returns true if the block attached to each connector in the given container are published

Returns:

  • (Boolean)


277
278
279
280
281
# File 'app/models/page.rb', line 277

def container_published?(container)
  connectors.for_page_version(draft.version).in_container(container.to_s).all? do |c| 
    c.connectable_type.constantize.publishable? ? c.connectable.live? : true
  end
end

#copy_connectors(options = {}) ⇒ Object

Each time a page is updated, we need to copy all connectors associated with it forward, and save them.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'app/models/page.rb', line 94

def copy_connectors(options={})
  logger.debug {"Copying connectors from Page #{id} v#{options[:from_version_number]} to v#{options[:to_version_number]}." }

  c_found = connectors.for_page_version(options[:from_version_number]).all(:order => "connectors.container, connectors.position")
  logger.debug {"Found connectors #{c_found}" }
  c_found.each do |c|
    # The connector won't have a connectable if it has been deleted
    # Also need to see if the draft has been deleted,
    # in which case we are in the process of deleting it
    if c.should_be_copied?
      logger.debug { "Connector id=>#{c.id} should be copied." }
      connectable = c.connectable_type.constantize.versioned? ? c.connectable.as_of_version(c.connectable_version) : c.connectable

      version = connectable.class.versioned? ? connectable.version : nil

      #If we are copying connectors from a previous version, that means we are reverting this page,
      #in which case we should create a new version of the block, and connect this page to that block.
      #If the connectable is versioned, the connector needs to reference the newly drafted connector
      #that is created during the revert_to method
      if @copy_connectors_from_version && connectable.class.versioned? && (connectable.version != connectable.draft.version)
        connectable = connectable.class.find(connectable.id)
        connectable.updated_by_page = self
        connectable.revert_to(c.connectable_version)
        version = connectable.class.versioned? ? connectable.draft.version : nil
      end      

      logger.debug "When copying block #{connectable.inspect} version is '#{version}'"

      new_connector = connectors.create(
        :page_version => options[:to_version_number], 
        :connectable => connectable, 
        :connectable_version => version,
        :container => c.container, 
        :position => c.position
      )
      logger.debug {"Built new connector #{new_connector}."}
    end
  end
  true
end

#create_connector(connectable, container = :main) ⇒ Object Also known as: add_content

Adds a Content block to this page.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'app/models/page.rb', line 138

def create_connector(connectable, container=:main)
  transaction do
    raise "Connectable is nil" unless connectable
    raise "Container is required" if container.blank?
    update_attributes(
      :version_comment => "#{connectable} was added to the '#{container}' container",
      :publish_on_save => (
        published? && 
        connectable.connected_page && 
        (connectable.class.publishable? ? connectable.published? : true)))
    connectors.create(
      :page_version => draft.version,
      :connectable => connectable,
      :connectable_version => connectable.class.versioned? ? connectable.version : nil, 
      :container => container)      
  end
end

#current_taskObject



305
306
307
# File 'app/models/page.rb', line 305

def current_task
  tasks.incomplete.first
end

#delete_connectorsObject

Pages that get deleted should be ‘disconnected’ from any blocks they were associated with.



188
189
190
# File 'app/models/page.rb', line 188

def delete_connectors
  connectors.for_page_version(version).all.each{|c| c.destroy }
end

#file_sizeObject



199
200
201
# File 'app/models/page.rb', line 199

def file_size
  "?"
end

#in_section?(section_or_section_name) ⇒ Boolean

Returns:

  • (Boolean)


268
269
270
271
272
273
274
# File 'app/models/page.rb', line 268

def in_section?(section_or_section_name)
  sec = section_or_section_name.is_a?(String) ? 
    Section.first(:conditions => {:name => section_or_section_name}) : 
    section_or_section_name
  fn = lambda{|s| s ? (s == sec || fn.call(s.parent)) : false}
  fn.call(section)
end

#layoutObject



251
252
253
# File 'app/models/page.rb', line 251

def layout
  template_file_name && "templates/#{template_file_name.split('.').first}"
end

#move_connector(connector, direction) ⇒ Object



157
158
159
160
161
162
163
164
165
# File 'app/models/page.rb', line 157

def move_connector(connector, direction)
  transaction do
    raise "Connector is nil" unless connector
    raise "Direction is nil" unless direction
    orientation = direction[/_/] ? "#{direction.sub('_', ' the ')} of" : "#{direction} within"
    update_attributes(:version_comment => "#{connector.connectable} was moved #{orientation} the '#{connector.container}' container")
    connectors.for_page_version(draft.version).like(connector).first.send("move_#{direction}")
  end    
end

#name_with_section_pathObject



292
293
294
295
# File 'app/models/page.rb', line 292

def name_with_section_path
  a = ancestors
  (a[1..a.size].map{|a| a.name} + [name]).join(" / ")
end

#page_titleObject



227
228
229
# File 'app/models/page.rb', line 227

def page_title
  title.blank? ? name : title
end

#path_not_reservedObject



245
246
247
248
249
# File 'app/models/page.rb', line 245

def path_not_reserved
  if Cms.reserved_paths.include?(path)
    errors.add(:path, "is invalid, '#{path}' a reserved path")
  end
end

#public?Boolean

Returns:

  • (Boolean)


223
224
225
# File 'app/models/page.rb', line 223

def public?
  section ? section.public? : false
end

#remove_connector(connector) ⇒ Object



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'app/models/page.rb', line 173

def remove_connector(connector)
  transaction do
    raise "Connector is nil" unless connector
    update_attributes(:version_comment => "#{connector.connectable} was removed from the '#{connector.container}' container")
    
    #The logic of this is to go ahead and let the container get copied forward, then delete the new connector
    if new_connector = connectors.for_page_version(draft.version).like(connector).first
      new_connector.destroy
    else
      raise "Error occurred while trying to remove connector #{connector.id}"
    end
  end
end

#remove_trailing_slash_from_pathObject

remove trailing slash, unless the path is only a slash. uses capture and substition because ruby regex engine does not support lookbehind



241
242
243
# File 'app/models/page.rb', line 241

def remove_trailing_slash_from_path
  self.path.sub!(/(.+)\/+$/, '\1') 
end

#revert_to(version) ⇒ Object

This is done to let copy_connectors know which version to pull from copy_connectors will get called later as an after_update callback



194
195
196
197
# File 'app/models/page.rb', line 194

def revert_to(version)
  @copy_connectors_from_version = version
  super(version)
end

#sectionObject



207
208
209
# File 'app/models/page.rb', line 207

def section
  section_node ? section_node.section : nil
end

#section=(sec) ⇒ Object



215
216
217
218
219
220
221
# File 'app/models/page.rb', line 215

def section=(sec)
  if section_node
    section_node.move_to_end(sec)
  else
    build_section_node(:node => self, :section => sec)
  end      
end

#section_idObject



203
204
205
# File 'app/models/page.rb', line 203

def section_id
  section ? section.id : nil
end

#section_id=(sec_id) ⇒ Object



211
212
213
# File 'app/models/page.rb', line 211

def section_id=(sec_id)
  self.section = Section.find(sec_id)
end

#templateObject

This will be nil if it is a file system based template



256
257
258
# File 'app/models/page.rb', line 256

def template
  PageTemplate.find_by_file_name(template_file_name)
end

#template_nameObject



260
261
262
# File 'app/models/page.rb', line 260

def template_name
  template_file_name && PageTemplate.display_name(template_file_name)
end

#top_level_sectionObject

This will return the “top level section” for a page, which is the section directly below the root (a.k.a My Site) that this page is in. If this page is in root, then this will return root.



300
301
302
303
# File 'app/models/page.rb', line 300

def top_level_section
  a = ancestors
  (a.size > 0 && ancestors[1]) ? ancestors[1] : Section.root.first
end